@@ -65,44 +65,6 @@ protected:
 
 public:
 
-    /// \brief A container of the textual command sent to the debugger
-    class Command {
-        UString m_value ;
-        UString m_tag0 ;
-        UString m_tag1 ;
-
-    public:
-
-        Command ()  {clear ();}
-
-        /// \param a_value a textual command to send to the debugger.
-        Command (const string &a_value) :
-            m_value (a_value)
-        {}
-
-        /// \name accesors
-
-        /// @{
-
-        const UString& value () const {return m_value;}
-        void value (const UString &a_in) {m_value = a_in;}
-
-        const UString& tag0 () const {return m_tag0;}
-        void tag0 (const UString &a_in) {m_tag0 = a_in;}
-
-        const UString& tag1 () const {return m_tag1;}
-        void tag1 (const UString &a_in) {m_tag1 = a_in;}
-
-        /// @}
-
-        void clear ()
-        {
-            m_tag0 = "" ;
-            m_tag1 = "" ;
-            m_value = "" ;
-        }
-
-    };//end class Command
 
     /// \brief a breakpoint descriptor
     class BreakPoint {
@@ -167,7 +129,7 @@ public:
     /// \brief a function frame as seen by the debugger.
     class Frame {
         UString m_address ;
-        UString m_function ;
+        UString m_function_name ;
         map<UString, UString> m_args ;
         int m_level ;
         //present if the target has debugging info
@@ -187,8 +149,8 @@ public:
         const UString& address () const {return m_address;}
         void address (const UString &a_in) {m_address = a_in;}
 
-        const UString& function () const {return m_function;}
-        void function (const UString &a_in) {m_function = a_in;}
+        const UString& function_name () const {return m_function_name ;}
+        void function_name (const UString &a_in) {m_function_name = a_in;}
 
         const map<UString, UString>& args () const {return m_args;}
         map<UString, UString>& args () {return m_args;}
@@ -214,7 +176,7 @@ public:
         void clear ()
         {
             m_address = "" ;
-            m_function = "" ;
+            m_function_name = "" ;
             m_args.clear () ;
             m_level = 0 ;
             m_file_name = "" ;
@@ -295,17 +257,18 @@ public:
                 a_str += value () ;
             }
             if (members ().empty ()) {
-                a_str += "\n" ;
                 return ;
             }
             UString indent_str = a_indent_str + "  " ;
-            a_str += "\n" + a_indent_str + "{\n";
+            a_str += "\n" + a_indent_str + "{";
             list<VariableSafePtr>::const_iterator it ;
             for (it = members ().begin () ; it != members ().end () ; ++it) {
                 if (!(*it)) {continue;}
+                a_str += "\n" ;
                 (*it)->to_string (a_str, true, indent_str) ;
             }
-            a_str += a_indent_str + "}\n" ;
+            a_str += "\n" + a_indent_str + "}";
+            a_str.chomp () ;
         }
 
         void build_qname (UString &a_qname) const
@@ -330,11 +293,32 @@ public:
     };//end class Variable
 
     enum State {
-        READY = 0,
+        NOT_STARTED=0,
+        READY,
         RUNNING,
         PROGRAM_EXITED
     };//enum State
 
+    static UString state_to_string (State a_state)
+    {
+        UString str ;
+        switch (a_state) {
+            case NOT_STARTED:
+                str = "NO_STARTED" ;
+                break;
+            case READY:
+                str = "READY" ;
+                break;
+            case RUNNING:
+                str = "RUNNING" ;
+                break ;
+            case PROGRAM_EXITED:
+                str = "PROGRAM_EXITED" ;
+                break ;
+        }
+        return str ;
+    }
+
 
     virtual ~IDebugger () {}
 
@@ -354,7 +338,12 @@ public:
 
     virtual sigc::signal<void, const UString&>& log_message_signal () const = 0 ;
 
-    virtual sigc::signal<void, const UString&>& command_done_signal () const = 0;
+    virtual sigc::signal<void,
+                         const UString&/*command name*/,
+                         const UString&/*command cookie*/>&
+                                                 command_done_signal () const = 0;
+
+    virtual sigc::signal<void>& detached_from_target_signal () const = 0 ;
 
     virtual sigc::signal<void, const IDebugger::BreakPoint&, int>&
                                          breakpoint_deleted_signal () const  = 0;
@@ -408,6 +397,9 @@ public:
                          const UString&/*type*/>&
                                         variable_type_signal () const = 0 ;
 
+    virtual sigc::signal<void, const vector<UString>& >&
+                            files_listed_signal () const = 0;
+
     virtual sigc::signal<void,
                          int/*pid*/,
                          const UString&/*target path*/>&
@@ -434,98 +426,109 @@ public:
 
     virtual void run_loop_iterations (int a_nb_iters) = 0;
 
+    /*
     virtual void execute_command (const Command &a_command) = 0;
 
-    virtual bool queue_command (const Command &a_command,
-                                bool a_run_event_loop=false) = 0;
+    virtual bool queue_command (const Command &a_command) = 0;
+    */
 
     virtual bool busy () const = 0;
 
     virtual void load_program
                 (const vector<UString> &a_argv,
+                 const UString &working_dir,
                  const vector<UString> &a_source_search_dirs,
-                 const UString &a_tty_path="",
-                 bool a_run_event_loops=false) = 0;
+                 const UString &a_tty_path="") = 0;
 
     virtual void load_core_file (const UString &a_prog_file,
-                                 const UString &a_core_file,
-                                 bool a_run_event_loop=false) = 0;
+                                 const UString &a_core_file) = 0;
 
-    virtual bool attach_to_program (unsigned int a_pid,
+    virtual bool attach_to_target (unsigned int a_pid,
                                     const UString &a_tty_path="") = 0;
 
+    virtual void detach_from_target (const UString &a_cookie="") = 0;
+
     virtual void add_env_variables (const map<UString, UString> &a_vars) = 0;
 
     virtual map<UString, UString>& get_env_variables () = 0 ;
 
     virtual const UString& get_target_path () = 0 ;
 
-    virtual void do_continue (bool a_run_event_loops=false) = 0;
+    virtual void do_continue (const UString &a_cookie="") = 0;
 
-    virtual void run (bool a_run_event_loops=false) = 0 ;
+    virtual void run (const UString &a_cookie="") = 0 ;
 
-    virtual void get_target_info (bool a_run_event_loops=false) = 0 ;
+    virtual void get_target_info (const UString &a_cookie="") = 0 ;
 
-    virtual bool stop (bool a_run_event_loops=false) = 0 ;
+    virtual IDebugger::State get_state () const = 0;
 
-    virtual void step_in (bool a_run_event_loops=false) = 0;
+    virtual bool stop_target () = 0 ;
 
-    virtual void step_over (bool a_run_event_loops=false) = 0;
+    virtual void exit_engine () = 0 ;
 
-    virtual void step_out (bool a_run_event_loops=false) = 0;
+    virtual void step_in (const UString &a_cookie="") = 0;
+
+    virtual void step_over (const UString &a_cookie="") = 0;
+
+    virtual void step_out (const UString &a_cookie="") = 0;
 
     virtual void continue_to_position (const UString &a_path,
                                        gint a_line_num,
-                                       bool a_run_event_loops=false ) = 0 ;
+                                       const UString &a_cookie="") = 0 ;
     virtual void set_breakpoint (const UString &a_path,
                                  gint a_line_num,
-                                 bool a_run_event_loops=false) = 0 ;
+                                 const UString &a_cookie="") = 0 ;
     virtual void set_breakpoint (const UString &a_func_name,
-                                 bool a_run_event_loops=false) = 0 ;
+                                 const UString &a_cookie="") = 0 ;
 
-    virtual void list_breakpoints (bool a_run_event_loops=false) = 0 ;
+    virtual void list_breakpoints (const UString &a_cookie="") = 0 ;
 
     virtual const map<int, BreakPoint>& get_cached_breakpoints () = 0 ;
 
     virtual void enable_breakpoint (const UString &a_path,
                                     gint a_line_num,
-                                    bool a_run_event_loops=false) = 0;
+                                    const UString &a_cookie="") = 0;
 
     virtual void disable_breakpoint (const UString &a_path,
                                      gint a_line_num,
-                                     bool a_run_event_loops=false) = 0;
+                                     const UString &a_cookie="") = 0;
 
     virtual void delete_breakpoint (const UString &a_path,
                                     gint a_line_num,
-                                    bool a_run_event_loops=false) = 0;
+                                    const UString &a_cookie="") = 0;
 
     virtual void delete_breakpoint (gint a_break_num,
-                                    bool a_run_event_loops=false) = 0;
+                                    const UString &a_cookie="") = 0;
 
-    virtual void list_threads (bool a_run_event_loops=false) = 0 ;
+    virtual void list_threads (const UString &a_cookie="") = 0 ;
 
     virtual void select_thread (unsigned int a_thread_id,
-                                bool a_run_event_loops=false) = 0;
+                                const UString &a_cookie="") = 0;
 
-    virtual void list_frames (bool a_run_event_loops=false) = 0;
+    virtual void select_frame (int a_frame_id,
+                               const UString &a_cookie="") = 0;
+
+    virtual void list_frames (const UString &a_cookie="") = 0;
 
     virtual void list_frames_arguments (int a_low_frame=-1,
                                         int a_high_frame=-1,
-                                        bool a_run_event_loops=false) = 0;
+                                        const UString &a_cookie="") = 0;
 
-    virtual void list_local_variables (bool a_run_event_loops=false)  = 0;
+    virtual void list_local_variables (const UString &a_cookie="")  = 0;
 
     virtual void evaluate_expression (const UString &a_expr,
-                                      bool a_run_event_loops=false)  = 0;
+                                      const UString &a_cookie="")  = 0;
 
     virtual void print_variable_value (const UString &a_var_name,
-                                       bool a_run_event_loops=false)  = 0;
+                                       const UString &a_cookie="")  = 0;
 
     virtual void print_pointed_variable_value (const UString &a_var_name,
-                                               bool a_run_event_loops=false) = 0;
+                                               const UString &a_cookie="") = 0;
 
     virtual void print_variable_type (const UString &a_var_name,
-                                      bool a_run_event_loops=false) = 0;
+                                      const UString &a_cookie="") = 0;
+
+    virtual void list_files (const UString &a_cookie="") = 0 ;
 
 };//end IDebugger
 
